@@ -63,6 +63,11 @@ Each command-line option can be abbreviated or used in long-form.
 
  --kill,-k       Kill any running lsm process.
 
+ --flush,-f      Flush all firewall chains and rules. If not given, then
+                 the default is to try to keep custom iptables rules 
+                 introduced by firewall utilities such as fail2ban and
+                 miniunpnpd.
+
  --help,-h       Print this message.
 
 =head1 COMMON USAGE
@@ -187,16 +192,20 @@ License 2.0.
 use strict;
 use Net::ISP::Balance;
 use Sys::Syslog;
+use Fcntl ':flock';
+use File::Spec;
 use Getopt::Long qw(:config no_ignore_case);
 use Carp 'croak';
 use Pod::Usage 'pod2usage';
+use constant LOCK_TIMEOUT => 30;  # if two processes running simultaneously, length of time second will wait for first
 
-my ($DEBUG,$VERBOSE,$STATUS,$KILL,$HELP,$VERSION);
+my ($DEBUG,$VERBOSE,$STATUS,$KILL,$HELP,$FLUSH,$VERSION);
 my $result = GetOptions('debug' => \$DEBUG,
 			'verbose'=>\$VERBOSE,
 			'Version'=>\$VERSION,
 			'status' => \$STATUS,
 			'kill'   => \$KILL,
+			'flush'  => \$FLUSH,
 			'help'   => \$HELP,
     );
 if (!$result || $HELP) {
@@ -210,6 +219,9 @@ if ($VERSION) {
     exit 0;
 }
 
+my $lock_fh = do_lock();
+END { do_unlock($lock_fh); }
+
 # command line arguments correspond to the ISP services (defined in the config file)
 # that are "up". LAN services are assumed to be always up.
 
@@ -222,6 +234,7 @@ fatal_error("Could not initialize balancer; maybe some interfaces are unavailabl
 
 $bal->echo_only($DEBUG);
 $bal->verbose($VERBOSE);
+$bal->keep_custom_chains(!$FLUSH);
 
 # these two subroutines exit
 do_status()   if $STATUS;
@@ -310,3 +323,31 @@ sub fatal_error {
     syslog('crit',$msg);
     croak $msg,"\n";
 }
+
+sub do_lock {
+    my $lockfile = File::Spec->catfile(File::Spec->tmpdir,
+				       "load_balance.$>.lock");
+    open (my $fh,'>>',$lockfile) or fatal_error("Can't open $lockfile for locking");
+    eval {
+	local $SIG{ALRM} = sub { die "timeout" };
+	alarm(LOCK_TIMEOUT);
+	flock($fh,LOCK_EX)            or fatal_error("Can't lock $lockfile");
+	alarm(0);
+    };
+    fatal_error("Lock timed out") if $@ =~ /timeout/;
+    return $fh;
+}
+
+
+sub do_unlock {
+    my $fh = shift;
+    return unless $fh;
+    flock($fh,LOCK_UN);
+    my $lockfile = get_lockfile();
+    unlink $lockfile;
+}
+
+sub get_lockfile {
+    return File::Spec->catfile(File::Spec->tmpdir,
+			       "load_balance.$>.lock");
+}
